Security Advisories (10)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CVE-2018-25100 (2018-02-13)

Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.

CPANSA-Mojolicious-2015-01 (2015-02-02)

Directory traversal on Windows

CPANSA-Mojolicious-2018-03 (2018-05-19)

Mojo::UserAgent was not checking peer SSL certificates by default.

CVE-2020-36829 (2020-11-10)

Mojo::Util secure_compare can leak the string length. By immediately returning when the two strings are not the same length, the function allows an attacker to guess the length of the secret string using timing attacks.

CPANSA-Mojolicious-2018-02 (2018-05-11)

GET requests with embedded backslashes can be used to access local files on Windows hosts

CPANSA-Mojolicious-2014-01 (2014-10-07)

Context sensitivity of method param could lead to parameter injection attacks.

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

NAME

Mojolicious::Command - Command base class

SYNOPSIS

# Lower case command name
package Mojolicious::Command::mycommand;
use Mojo::Base 'Mojolicious::Command';

# Short description
has description => "My first Mojo command.\n";

# Short usage message
has usage => <<"EOF";
usage: $0 mycommand [OPTIONS]

These options are available:
  -s, --something   Does something.
EOF

# <suitable Futurama quote here>
sub run {
  my ($self, @args) = @_;

  # Magic here! :)
}

DESCRIPTION

Mojolicious::Command is an abstract base class for Mojolicious commands.

See Mojolicious::Commands for a list of commands that are available by default.

ATTRIBUTES

Mojolicious::Command implements the following attributes.

app

my $app  = $command->app;
$command = $command->app(MyApp->new);

Application for command, defaults to a Mojo::HelloWorld object.

# Introspect
say "Template path: $_" for @{$command->app->renderer->paths};

description

my $description = $command->description;
$command        = $command->description('Foo!');

Short description of command, used for the command list.

quiet

my $quiet = $command->quiet;
$command  = $command->quiet(1);

Limited command output.

usage

my $usage = $command->usage;
$command  = $command->usage('Foo!');

Usage information for command, used for the help screen.

METHODS

Mojolicious::Command inherits all methods from Mojo::Base and implements the following new ones.

chmod_file

$command = $command->chmod_file('/home/sri/foo.txt', 0644);

Change mode of a file.

chmod_rel_file

$command = $command->chmod_rel_file('foo/foo.txt', 0644);

Portably change mode of a file relative to the current working directory.

create_dir

$command = $command->create_dir('/home/sri/foo/bar');

Create a directory.

create_rel_dir

$command = $command->create_rel_dir('foo/bar/baz');

Portably create a directory relative to the current working directory.

help

$command->help;

Print usage information for command.

rel_dir

my $path = $command->rel_dir('foo/bar');

Portably generate an absolute path for a directory relative to the current working directory.

rel_file

my $path = $command->rel_file('foo/bar.txt');

Portably generate an absolute path for a file relative to the current working directory.

render_data

my $data = $command->render_data('foo_bar');
my $data = $command->render_data('foo_bar', @args);

Render a template from the DATA section of the command class with Mojo::Template.

render_to_file

$command = $command->render_to_file('foo_bar', '/home/sri/foo.txt');
$command = $command->render_to_file('foo_bar', '/home/sri/foo.txt', @args);

Render a template from the DATA section of the command class with Mojo::Template to a file and create directory if necessary.

render_to_rel_file

$command = $command->render_to_rel_file('foo_bar', 'foo/bar.txt');
$command = $command->render_to_rel_file('foo_bar', 'foo/bar.txt', @args);

Portably render a template from the DATA section of the command class with Mojo::Template to a file relative to the current working directory and create directory if necessary.

run

$command->run;
$command->run(@ARGV);

Run command. Meant to be overloaded in a subclass.

write_file

$command = $command->write_file('/home/sri/foo.txt', 'Hello World!');

Write text to a file and create directory if necessary.

write_rel_file

$command = $command->write_rel_file('foo/bar.txt', 'Hello World!');

Portably write text to a file relative to the current working directory and create directory if necessary.

SEE ALSO

Mojolicious, Mojolicious::Guides, http://mojolicio.us.